pro get_sscinfo,index,sxt1,sxt2,sxt3

;+
; NAME
;	get_sscinfo
; PURPOSE
;	To quickly collect the information for the exposures
;	comprising an SSC or SST.
; CALLING SEQUENCE
;	get_sscinfo,index,sst=sst,sxt1,sxt2 [,sxt3]
; INPUT
;	index, SSC or SST index structure.
; OUTPUT
;	sxt1: array of index structures for the short exposure
;	sxt2: array of index structures for the long exposure
;	  Note: For single-exposure SSCs then sxt1=sxt2.
; OPTIONAL OUTPUT
;	sxt3: for SST, index structures for the super-long exposure.
;	  Note: For double-exposure SSTs then sxt1=sxt2 and sxt3
;		refers to the super_long exposure.
;		If sxt3 is asked for when SSC index is input then
;		sxt3 remains undefined.
; HISTORY
; 	Journal File for acton@pachyderm.physics.montana.edu
; 	Working directory: /disk/pd1/acton/movietime
; 	Date: Fri Nov 12 10:23:25 2004  (LWA)
;	17-Nov-2004 LWA  Changed loop indices to longword.
;			 Handle no-short SSCs and SSTs.
;-

if max(index.his.time_compos(2)) gt 0 then sst=1 else sst=0

img1={time:0L,day:0,comp:'img1'}
img1=replicate(img1,n_elements(index))
img2={time:0L,day:0,comp:'img2'}
img2=replicate(img2,n_elements(index))
if sst then begin
   img3={time:0L,day:0,comp:'img3'}
   img3=replicate(img3,n_elements(index))
endif

if not sst then begin
   for i=0L,n_elements(index)-1 do begin
      case 1 of
         index(i).his.time_compos(0) ne 0 : begin
            img1(i).time=index(i).his.time_compos(0)
            img1(i).day=index(i).his.day_compos(0)
            img2(i).time=index(i).his.time_compos(1)
            img2(i).day=index(i).his.day_compos(1)
         end
         index(i).his.time_compos(0) eq 0 : begin
            img2(i).time=index(i).gen.time
	    img2(i).day=index(i).gen.day
         end
      endcase
   endfor
endif else begin
   for i=0L,n_elements(index)-1 do begin
      case 1 of
         index(i).his.time_compos(2) ne 0 : begin
            img1(i).time=index(i).his.time_compos(0)
            img1(i).day=index(i).his.day_compos(0)
            img2(i).time=index(i).his.time_compos(1)
            img2(i).day=index(i).his.day_compos(1)
            img3(i).time=index(i).his.time_compos(2)
            img3(i).day=index(i).his.day_compos(2)
         end
         index(i).his.time_compos(2) eq 0 : begin
            img1(i).time=index(i).his.time_compos(0)
            img1(i).day=index(i).his.day_compos(0)
            img2(i).time=index(i).his.time_compos(0)
            img2(i).day=index(i).his.day_compos(0)
            img3(i).time=index(i).his.time_compos(1)
            img3(i).day=index(i).his.day_compos(1)
         end
      endcase
   endfor
endelse

rd_obs,img2(0),img2(0),bcs,sxtf,/nobcs,/quiet
sxt1=replicate(sxtf,n_elements(index))
sxt2=replicate(sxtf,n_elements(index))

for i=0L,n_elements(index)-1 do begin
   case 1 of
      img1(i).time ne 0 : begin
         rd_obs,img1(i),img1(i),bcs,sxtg,/nobcs,/quiet
         sxt1(i)=sxtg
         rd_obs,img2(i),img2(i),bcs,sxtg,/nobcs,/quiet
         sxt2(i)=sxtg
      end
      img1(i).time eq 0 : begin
         rd_obs,img2(i),img2(i),bcs,sxtg,/nobcs,/quiet
	 sxt1(i)=sxtg
	 sxt2(i)=sxtg
      end
   endcase
endfor

if sst then begin	;SST case.
   sxt3=replicate(sxtf,n_elements(index))
   for i=0L,n_elements(index)-1 do begin
      rd_obs,img3(i),img3(i),bcs,sxtg,/nobcs,/quiet
      sxt3(i)=sxtg
   endfor
endif

end
